@@ -252,11 +252,16 @@ fn validate_struct(ast: &syn::DeriveInput, limbs: usize) -> Option<proc_macro2::
     }
 
     // The array's length should be a literal int equal to `limbs`.
-    let lit_int = match match &arr.len {
-        syn::Expr::Lit(expr_lit) => match &expr_lit.lit {
-            syn::Lit::Int(lit_int) => Some(lit_int),
+    let expr_lit = match &arr.len {
+        syn::Expr::Lit(expr_lit) => Some(&expr_lit.lit),
+        syn::Expr::Group(expr_group) => match &*expr_group.expr {
+            syn::Expr::Lit(expr_lit) => Some(&expr_lit.lit),
             _ => None,
-        },
+        }
+        _ => None
+    };
+    let lit_int = match match expr_lit {
+        Some(syn::Lit::Int(lit_int)) => Some(lit_int),
         _ => None,
     } {
         Some(x) => x,
@@ -888,11 +893,32 @@ fn prime_field_impl(
 
     let from_repr_impl = endianness.from_repr(name, limbs);
     let to_repr_impl = endianness.to_repr(quote! {#repr}, &mont_reduce_self_params, limbs);
-    let to_le_bits_impl = ReprEndianness::Little.to_repr(
-        quote! {::ff::derive::bitvec::array::BitArray::new},
-        &mont_reduce_self_params,
-        limbs,
-    );
+
+    cfg_if::cfg_if! {
+        if #[cfg(feature = "bits")] {
+            let to_le_bits_impl = ReprEndianness::Little.to_repr(
+                quote! {::ff::derive::bitvec::array::BitArray::new},
+                &mont_reduce_self_params,
+                limbs,
+            );
+
+            let prime_field_bits_impl = quote! {
+                impl ::ff::PrimeFieldBits for #name {
+                    type ReprBits = REPR_BITS;
+
+                    fn to_le_bits(&self) -> ::ff::FieldBits<REPR_BITS> {
+                        #to_le_bits_impl
+                    }
+
+                    fn char_le_bits() -> ::ff::FieldBits<REPR_BITS> {
+                        ::ff::FieldBits::new(MODULUS)
+                    }
+                }
+            };
+        } else {
+            let prime_field_bits_impl = quote! {};
+        }
+    };
 
     let top_limb_index = limbs - 1;
 
@@ -1192,17 +1218,7 @@ fn prime_field_impl(
             }
         }
 
-        impl ::ff::PrimeFieldBits for #name {
-            type ReprBits = REPR_BITS;
-
-            fn to_le_bits(&self) -> ::ff::FieldBits<REPR_BITS> {
-                #to_le_bits_impl
-            }
-
-            fn char_le_bits() -> ::ff::FieldBits<REPR_BITS> {
-                ::ff::FieldBits::new(MODULUS)
-            }
-        }
+        #prime_field_bits_impl
 
         impl ::ff::Field for #name {
             /// Computes a uniformly random element using rejection sampling.
